#!/usr/bin/env python
#-*- coding:utf-8 –*-
#-----------------------------------------------------------------------------
# $Header: $
#-----------------------------------------------------------------------------
# Summary:          Implementation of Device Connection
#  
# Authors:          Jensen.Cai
#
# Started:          11/25/2014
#
# Version:          V1.7R1
#
# Copyright 2013-2016 Siglent Corporation. All Rights Reserved.
#
#-----------------------------------------------------------------------------

from visa import *
import re, time

#------------------------
# DevConn class
#------------------------
class DevConn(object):
    def __init__(self):
        self.list = []
        self.dict = {}
        self.__sort()
        
    def __sort(self):
        #获取设备列表并分类
        try:
            self.list = get_instruments_list()
        except:
            print u'没有找到任何设备，请检查是否已正确连接'
            raw_input('No Instrument Found')
            exit()
        for dev in self.list:
            if re.search('SDG', dev):
                self.dict['SDG'] = dev
            elif re.search('SDS', dev):
                self.dict['SDS'] = dev
            elif re.search('SDM', dev):
                self.dict['DMM'] = dev
            elif re.search('SPD', dev):
                self.dict['SPD'] = dev
            #先按照Siglent设备的序列号进行分类，非Siglent设备则通过IDN返回值进行分类
            elif re.search('USB0', dev):
                self.__match(dev)
            elif re.search('GPIB0', dev):
                self.__match(dev + '::INSTR')
            else:
                pass
    
    def __match(self,  dev_id):
        test_instr = instrument(dev_id)
        dev_info = test_instr.ask('*IDN?')
        if re.search('SDG', dev_info):
           dev_model = 'SDG'
        elif re.search('SDS', dev_info):
            dev_model = 'SDS'
        elif re.search('SDM', dev_info) or \
             re.search('DM', dev_info):
            dev_model = 'DMM'
        elif re.search('Agilent', dev_info) or \
             re.search('Keysight', dev_info):
            if re.search('U200', dev_info):
                dev_model = 'PowerSensor'
            elif re.search('34461', dev_info):
                dev_model = 'DMM'
        elif re.search('34401', dev_info):
            dev_model = 'DMM'
        else:
            try:
                pri_idn = test_instr.ask('IDN-SGLT-PRI?')
                if re.search('SDG', pri_idn):
                    dev_model = 'SDG'
                elif re.search('SDS', pri_idn):
                    dev_model = 'SDS'
                elif re.search('SDM', pri_idn):
                    dev_model = 'DMM'
                elif re.search('SPD', pri_idn):
                    dev_model = 'SPD'
                else:
                    pass
            except:
                print u'请检查设备是否符合测试环境的要求'
                raw_input('Unexpected device in the required test environment')
                exit()
        self.dict[dev_model] = dev_id
        
    def connect(self, dev_symbol):
        #连接需要使用的设备
        for dev_name in self.dict:
            if re.match(dev_symbol, dev_name):
                conn_instr = instrument(self.dict[dev_name],timeout = 5)
                return conn_instr
        else:
            print u'没有找到%s标识的设备，请检查该设备是否已正确连接' % dev_symbol
            raw_input('No %s Instrumnet' % dev_symbol)
            exit()

#-----------------------------------------------------------------------------
if __name__ == '__main__':
    device = DevConn()
    SDG = device.connect('SDG')
    info=SDG.ask('*IDN?')
    print info
    raw_input()
