#!/usr/bin/env python
#-*- coding:utf-8 –*-
#-----------------------------------------------------------------------------
# $Header: $
#-----------------------------------------------------------------------------
# Summary:		Implementation of Device Remote Control
#
# Authors:		Jensen.Cai
#  
# Started:		4/20/2015
#
# Version:          V1.7R1
#
# Copyright 2013-2016 Siglent Corporation. All Rights Reserved.
#
#-----------------------------------------------------------------------------

from device_connect import *
import time

__metaclass__ = type

device = DevConn()

class SDGRemote:
    def __init__(self):
        #device = DevConn() #QA6台联检时应加入该句以保证在更换机器时刷新设备列表
        self.sdg = device.connect('SDG')
        self.sdg_idn = self.sdg.ask('*IDN?')
        self.model = self.sdg.ask('PROD MODEL?').split(',')[-1]
        self.band =  int(sum(self.sdg.ask_for_values('PROD BAND?')))
    def get_idn(self): 
        return self.sdg_idn
    def get_sdg_sign(self):
        return self.sdg_idn[5:8]
    def get_product(self):
        return self.sdg_idn.split(',')[1]
    def get_SN(self):
        return self.sdg_idn.split(',')[2]
    def get_version(self):
        return self.sdg_idn.split(',')[3]
    def get_model(self):
        return self.model
    def get_band(self):
        return self.band
    def set_bswv(self, ch, wvtp, frq, amp, ofst=0, phase=0):
        self.sdg.write('%s:BSWV WVTP,%s,FRQ,%s,AMP,%s,OFST,%s,PHSE,%s' % (ch, wvtp, frq, amp, ofst, phase))
        time.sleep(3)
    def set_wvtp(self, ch, wvtp):
        self.sdg.write('%s:BSWV WVTP,%s' % (ch, wvtp))
        time.sleep(1)
    def set_frq(self, ch, frq):
        self.sdg.write('%s:BSWV FRQ,%s' % (ch, frq))
        time.sleep(1)
    def set_amp(self, ch, amp):
        self.sdg.write('%s:BSWV AMP,%s' % (ch, amp))
        time.sleep(1)
    def set_duty(self, ch, duty):
        self.sdg.write('%s:BSWV DUTY,%s' % (ch, duty))
        time.sleep(1)
    def set_ofst(self, ch, ofst):
        self.sdg.write('%s:BSWV OFST,%s' % (ch, ofst))
        time.sleep(1)
    def set_dbm(self, ch, dbm):
        self.sdg.write('%s:AMPDBM %s' % (ch, dbm))
        time.sleep(1)
    def set_output(self, ch, state, load):
        self.sdg.write('%s:OUTP %s,LOAD,%s'% (ch, state, load))
        time.sleep(2)
    def set_output_on(self, ch):
        self.sdg.write('%s:OUTP ON'% ch)
        time.sleep(2)
    def set_output_off(self, ch):
        self.sdg.write('%s:OUTP OFF'% ch)
        time.sleep(1)
    def set_output_load(self, ch, load):
        self.sdg.write('%s:OUTP LOAD,%s'% (ch, load))
        time.sleep(2)
    def set_ipAddress(self, ip_add):
        self.sdg.write('SYST:COMM:LAN:IPAD %s' % ip_add)
        time.sleep(1)
    def set_subnetMask(self, subnet_mask):
        self.sdg.write('SYST:COMM:LAN:SMAS %s' % subnet_mask)
        time.sleep(1)
    def self_adjust(self):
        self.sdg.write('SLFCALI')
        time.sleep(60)
    def get_selfCal_state(self):
        selfCal_state = self.sdg.ask('SLFCALI?').split(',' )[1]
        if selfCal_state == 'complete':
            return 1
        elif selfCal_state == 'incomplete':
            return 0
    def save_adjData(self):
        self.sdg.write('SVAJTDT')
    def set_SN(self, serial_number):
        self.sdg.write('SRLN %s' % serial_number)
        time.sleep(3)
    def close(self):
        self.sdg.close()

class FBRemote(SDGRemote):
    def __init__(self):
        super(FBRemote, self).__init__()
        self.step = ['FIRST', 'SECOND', 'THIRD']
    def init_step(self):
        self.sdg.write('FeeDBacKAJusT STEP, INIT')
        time.sleep(1)
    def adjust_step(self, number):
        self.sdg.write('FeeDBacKAJusT STEP, %s' % self.step[number])
        time.sleep(2)
    def done_step(self):
        self.sdg.write('FeeDBacKAJusT STEP, DONE')
        time.sleep(1)
    def set_adjDC(self, dc_val):
        self.sdg.write('FeeDBacKAJusT DCOFST,%s' % dc_val)
        time.sleep(1)
    
class DCRemote(SDGRemote):
    def __init__(self):
        super(DCRemote, self).__init__()

class DutyRemote(SDGRemote):
    def __init__(self):
        super(DutyRemote, self).__init__()
    def adj_1st_step(self, ch, set_duty, meas_duty):
        self.sdg.write('%s:DuTyAJusT SETP,FIRST,SET_DUTY,%s,MEAS_DUTY,%s' % (ch, set_duty, meas_duty))
        time.sleep(1)
    def adj_2nd_step(self, ch, set_duty, meas_duty):
        self.sdg.write('%s:DuTyAJusT SETP,SECOND,SET_DUTY,%s,MEAS_DUTY,%s' % (ch, set_duty, meas_duty))
        time.sleep(1)
    def adj_done_step(self, ch):
        self.sdg.write('%s:DuTyAJusT SETP,DONE' % ch)
        time.sleep(1)
    def adjDuty(self, ch, duty, adj_sch):
        if adj_sch == '1-X':
            self.sdg.write('%s:DUTYCALI DUTY,%s' % (ch, duty))
        else:
            self.sdg.write('%s:DuTyAJusT DUTY,%s' % (ch, duty))
        time.sleep(2)
    def set_calData(self, ch, delta, slope):
        self.sdg.write('%s:DUTYCALI DELTA, %s, SLOPE,%s' % (ch, delta, slope))
        time.sleep(2)
        
class VARemote(SDGRemote):
    def __init__(self):
        super(VARemote, self).__init__()
    def set_lowFrqAdj_bswv(self, ch, frq, amp, ofst):
        self.sdg.write('%s:FreqReSPAJusT OSIG_FRQ,%s,OSIG_AMP,%s,OSIG_OFFSET,%s' % (ch, frq, amp, ofst))
        time.sleep(1)
    def set_lowFrqAdj_comp(self, ch, state, index, frq, comp):
        self.sdg.write('%s:FreqReSPAJusT STATE,%s,INDEX,%s,OSIG_FRQ,%s,LOWFREQ_COMP,%s' % (ch, state, index, frq, comp))
        time.sleep(0.5)

class FRRemote(SDGRemote):
    def __init__(self):
        super(FRRemote, self).__init__()
    def set_flatness_bswv(self, ch, frq, amp):
        self.sdg.write('%s:FreqReSPAJusT OSIG_FRQ,%s,OSIG_AMP,%s' % (ch, frq, amp))
        time.sleep(1)
    def set_flatness_comp(self, ch, state, index, frq, comp):
        self.sdg.write('%s:FreqReSPAJusT STATE,%s,INDEX,%s,OSIG_FRQ,%s,COMP,%s' % (ch, state, index, frq, comp))
        time.sleep(0.5)
    def set_multiComp(self, ch, amp, multi_comp):
        self.sdg.write('%s:FreqReSPAJusT OSIG_AMP,%s,MULTI_COMP,%s' % (ch, amp, multi_comp))
        time.sleep(1)

class FrqCntRemote(SDGRemote):
    def __init__(self, delay=5):
        super(FrqCntRemote, self).__init__()
        self.read_delay = delay
    def set_state_on(self):
        self.sdg.write('FCNT STATE,ON')
    def set_state_off(self):
        self.sdg.write('FCNT STATE,OFF')
    def set_refFrq(self, ref_frq):
        self.sdg.write('FCNT REFQ,%s' % ref_frq)
    def set_trgLvl(self, trg_lvl):
        self.sdg.write('FCNT TRG,%s' % trg_lvl)
    def set_coupMod(self, mode):
        self.sdg.write('FCNT MODE,%s' % mode)
    def set_hfr(self, hfr_state):
        self.sdg.write('FCNT HFR,%s' % hfr_state)
    def set_trgLvl_reg(self, write_val):
        self.sdg.write('FCNTCALI REG,%s' % write_val)
    def get_fcnt_data(self):
        time.sleep(self.read_delay)
        self.sdg.write('FCNT?') 
        time.sleep(1)
        return self.sdg.read()
    def get_frq(self):
        frq = float(self.get_fcnt_data().split(',')[3][:-2])
        return frq
    def get_duty(self):
        duty = float(self.get_fcnt_data().split(',')[5])
        return duty
    def get_pw(self):
        pw =  float(self.get_fcnt_data().split(',')[11])
        return pw
    def get_nw(self):
        nw =  float(self.get_fcnt_data().split(',')[13])
        return nw
    def get_calData(self):
        self.sdg.write('FCNTCALI?')
        time.sleep(1)
        return self.sdg.read()
    def get_trgLvl_reg(self):
        read_val = float(self.get_calData().split(',')[5])
        return read_val
    def set_calData(self, slope, delta):
        self.sdg.write('FCNTCALI SLOPE,%s,DELTA,%s' % (slope, delta))
        time.sleep(2)

class LANRemote(SDGRemote):
    def __init__(self):
        super(LANRemote, self).__init__()
        
class QARemote(SDGRemote):
    def __init__(self):
        super(QARemote, self).__init__()
        
#-----------------------------------------------------------------------------

class DMMRemote:
    def __init__(self):
        self.dmm = device.connect('DMM')
        self.dmm_idn = self.dmm.ask('*IDN?')
    def get_idn(self):
        return self.dmm_idn
    def set_default(self):
        self.dmm.write('*CLS')
        self.dmm.write('*RST')
        time.sleep(2)
    def set_mode(self,  mode):
        self.dmm.write('CONF:VOLT:%s' % mode)
        time.sleep(1)
    def get_value(self,  mode):
        #测量两次，保证准确度
        self.dmm.write('MEAS:VOLT:%s?' % mode)
        time.sleep(0.1)
        self.dmm.read()
        self.dmm.write('MEAS:VOLT:%s?' % mode)
        time.sleep(0.1)
        value = float(self.dmm.read())
        return value
    def close(self):
        self.dmm.close()

class SDSRemote:
    def __init__(self):
        self.sds = device.connect('SDS')
        self.sds_idn = self.sds.ask('*IDN?')
    def set_default(self):
        self.sds.write('*RST')
    def get_idn(self):
        return self.sds_idn
    def set_dutyMeas(self, adj_sch):
        self.sds.write('C1:TRA ON;C2:TRA OFF')
        self.sds.write('C1:TRLV 0')
        time.sleep(0.5)
        if adj_sch == '1-X':
            self.sds.write('TDIV 10NS;C1:VDIV 1')
            self.sds.write('C1:CPL D50')
        else:
            self.sds.write('TDIV 2.5US;C1:VDIV 1')
            self.sds.write('C1:CPL D1M')
        time.sleep(0.5)
        self.change_dutyStat()
        time.sleep(1)
    def set_5ns(self):
        self.sds.write('TDIV 5NS')
        time.sleep(1)
    def set_10ns(self):
        self.sds.write('TDIV 10NS') 
        time.sleep(1)
    def set_tdiv(self, value):
        self.sds.write('TDIV %s' % str(value))
        time.sleep(1)
    def set_1v(self):
        self.sds.write('C1:VDIV 1')
        time.sleep(1)
    def get_value(self):
        self.sds.write('PASTAT RESET')
        time.sleep(4)
        data_split = self.sds.ask('PAVA? STAT1').split(',')
        value = float(data_split[data_split.index('mean')+1][:-1])
        return value
    def change_dutyStat(self):
        self.sds.write('PACU DUTY,C1')
        self.sds.write('PASTAT ON')
    def close(self):
        self.sds.close()

class PowerSensorRemote:
    def __init__(self):
        self.powersensor = device.connect('PowerSensor')
        self.powersensor_idn = self.powersensor.ask('*IDN?')
    def get_idn(self):
        return self.powersensor_idn
    def preset(self):
        self.powersensor.write('SYST:PRES DEF')
        time.sleep(1)
    def set_frq(self, frq):
        self.powersensor.write('FREQ %s' % frq)
        time.sleep(0.2)
    def get_value(self):
        self.powersensor.write('FETC?')
        time.sleep(0.2)
        value = round(float(self.powersensor.read()),  4) #读完值后取小数点后四位
        return value
    def close(self):
        self.powersensor.close()
        
class SPDRemote:
    def __init__(self):
        self.spd = device.connect('SPD')
        self.spd_idn= self.spd.ask('*IDN?')
    def get_idn(self):
        return self.spd_idn
    def set_volt(self, ch, volt):
        self.spd.write('%s:VOLT %s' % (ch, volt))
        time.sleep(1)
    def output_on(self, ch):
        self.spd.write('OUTP %s,ON' % ch)
        time.sleep(3)
    def output_off(self, ch):
        self.spd.write('OUTP %s,OFF' % ch)
        time.sleep(3)
    def close(self):
        self.spd.close()

class SineTestRemote(SDGRemote):
    def __init__(self):
        super(SineTestRemote, self).__init__()

    def set_sine(self, ch):
        self.sdg.write('%s:BSWV WVTP,SINE,FRQ,11000000,AMP,1,OFST,0,PHSE,0' % (ch))
        time.sleep(2)

#-----------------------------------------------------------------------------
if __name__ == '__main__':
    a = SDGRemote()
