#!/usr/bin/env python
#-*- coding:utf-8 –*-
#-----------------------------------------------------------------------------
# $Header: $
#-----------------------------------------------------------------------------
# Summary:          Implementation of Parameter Initialization
#
# Authors:          Jensen.Cai
#
# Started:          11/25/2014
#
# Version:          V1.7R1
#  
# Copyright 2013-2016 Siglent Corporation. All Rights Reserved.
#
#-----------------------------------------------------------------------------

from device_remote import *
import re

#参数初始化：某些型号的变量并没有全部使用(取决于对应项目是否执行)。该文件中为了方便对比而统一了所有型号的变量个数。
class ParameterInit(SDGRemote):
    def __init__(self):
        super(ParameterInit, self).__init__()
        self.idn = self.get_idn()
        self.sign = self.get_sdg_sign()
        self.product = self.get_product()
        self.serial_num = self.get_SN()
        self.version = self.get_version()
        self.model = self.get_model()
        self.band = self.get_band()
        self.adjSch_init()
        self.save_time = 4
        
    def adjSch_init(self):
        #SDG800\SDG1000\SDG2000X均按最高带宽进行生产
        if self.model == 'SDG800':
            self.adj_sch = '0-0'
            self.cal_band = 30
        elif self.model == 'SDG1000':
            self.adj_sch = '1-0'
            self.cal_band = 50
        elif self.model == 'SDG5000':
            try:
                cpld_ver = int(self.idn.split(',')[4].split('-')[4])
            except:
                #有些贴牌机不体现机器型号，因此*IDN里少了一项
                cpld_ver = int(self.idn.split(',')[3].split('-')[4])
            ch_ver = 'D' #临时
            if cpld_ver < 35:
                self.adj_sch = '5-0'
            elif cpld_ver == 36:
                self.adj_sch = '5-2' #临时，最后应以后者为准
            elif cpld_ver >= 35 and (ch_ver == 'B' or ch_ver == 'D') :
                self.adj_sch = '5-1'
            else: #即CPLD≥35，且通道板为E版本以上
                self.adj_sch = '5-2'
            self.cal_band = self.band
        elif self.model == 'SDG2000X':
            self.adj_sch = '2-0'
            self.cal_band = 120
        elif self.model == 'SDG1000X':
            self.adj_sch = '1-X'
            self.cal_band = 60
        if 'SDG' not in self.serial_num:
            self.cal_band = self.band

class FBParam(ParameterInit):
    def __init__(self):
        super(FBParam, self).__init__()
        self.FB_config()
    def FB_config(self):
        if self.adj_sch == '5-0':
            self.FB_step = 2
            self.FB_volt = [1.0, -1.0]
            self.FB_err  = 0.001
        elif self.adj_sch in ['0-0', '1-0', '1-X', '5-1', '5-2', '2-0']:
            self.FB_step = 3
            self.FB_volt = [0, 1.0, -1.0]
            self.FB_err  = 0.0001

class DCParam(ParameterInit):
    def __init__(self):
        super(DCParam, self).__init__()
        self.DC_config()
    def DC_config(self):
        ch_list1   = ['C1', 'C2']
        ch_list2   = ['C1']
        ofst_list1 = [0,0.01,0.1,1,3,10,-10,-3,-1,-0.1,-0.01]
        ofst_list2 = [0,0.01,0.1,1,3,-3,-1,-0.1,-0.01]
        err1       = 0.001
        err2       = 0.0016
        err3       = 0.003
        
        if self.adj_sch == '0-0':
            self.DC_ch_list, self.DC_ch1_dclist, self.DC_ch2_dclist, self.DC_err = ch_list2, ofst_list1, ofst_list1, err3
        elif self.adj_sch == '1-0':
            if self.sign == 'WST':
                self.DC_ch_list, self.DC_ch1_dclist, self.DC_ch2_dclist, self.DC_err = ch_list1, ofst_list2, ofst_list1, err3
            else:
                self.DC_ch_list, self.DC_ch1_dclist, self.DC_ch2_dclist, self.DC_err = ch_list1, ofst_list1, ofst_list2, err3
        elif self.adj_sch in ['5-0', '5-1','5-2']:
            self.DC_ch_list, self.DC_ch1_dclist, self.DC_ch2_dclist, self.DC_err = ch_list1, ofst_list1, ofst_list1, err1
        elif self.adj_sch == '2-0':
            self.DC_ch_list, self.DC_ch1_dclist, self.DC_ch2_dclist, self.DC_err = ch_list1, ofst_list1, ofst_list1, err2
        elif self.adj_sch == '1-X':
            self.DC_ch_list, self.DC_ch1_dclist, self.DC_ch2_dclist, self.DC_err = ch_list1, ofst_list1, ofst_list1, err3

class SqrDutyParam(ParameterInit):
    def __init__(self):
        super(SqrDutyParam, self).__init__()
        self.SqrDuty_config()
    def SqrDuty_config(self):
        self.sqrDuty_ch_list = ['C1', 'C2']
        self.dutyCal_err  = 0.1
        if self.adj_sch == '1-X':
            self.dutyCal_duty = [41.0, 59.0]
            self.set_duty = [41.0, 59.0]
        else:
            self.dutyCal_duty = [20.0, 80.0]

class VAParam(ParameterInit):
    def __init__(self):
        super(VAParam, self).__init__()
        self.VA_config()
    def VA_config(self):
        self.VA_ch_list = ['C1', 'C2']
        self.VA_ofst_list  = [0,3.5]
        self.VA_frq        = 10000
        if self.adj_sch == '1-X':
            self.VA_amp_list  = [13.0,4.0,1.0,0.4,0.1,0.04,0.01,0.004]
        else:
            self.VA_amp_list  = [11.0,5.6,2.0,0.9,0.4,0.142,0.064,0.022,0.010,0.004]

class FRParam(ParameterInit):
    def __init__(self):
        super(FRParam, self).__init__()
        self.FR_config()
    def FR_config(self):
        ch_list1      = ['C1', 'C2']
        ch_list2      = ['C1']
        VertAcc_list1 = [18,10,4,-4,-12,-22,-28,-36]
        VertAcc_list2 = [10,4,-4,-12,-22,-28,-36]
        maxFrq_1 = self.cal_band
        maxFrq_2 = min(maxFrq_1, 100)
        maxFrq_3 = min(maxFrq_1, 130)
        err1 = 0.6
        err2 = 0.2
        err3 = 0.24
        state_list_1 = range(0, 2)
        state_list_2 = range(0, 8)
        amp_list_1 = [1.0, 2.5]
        amp_list_2 = [0.015, 0.025, 0.05, 0.15, 0.5, 1.0, 2.5, 5.0]
        dBm_list_1 = [3.9794, 11.94]
        dBm_list_2 = [-32.4988, -28.0618, -22.0412, -12.4988, -2.0412, 3.9794, 11.9382, 17.9588]
        
        self.ref_frq = 10000  #REFERENCE FRQ = 10kHz
        self.start_frq = 1000000
        if self.adj_sch == '0-0':
            self.FR_ch_list, self.FR_state, self.FR_amp, self.FR_dbm, self.FR_max_frq, self.FR_HF_err, self.FR_LF_err, self.FR_ch1_VAlist, self.FR_ch2_VAlist \
            = ch_list2, state_list_1, amp_list_1, dBm_list_1, [maxFrq_1, maxFrq_2], err1, err2, VertAcc_list2, VertAcc_list2
        elif self.adj_sch == '1-0':
            if self.sign == 'WST':
                self.FR_ch_list, self.FR_state, self.FR_amp, self.FR_dbm, self.FR_max_frq, self.FR_HF_err, self.FR_LF_err, self.FR_ch1_VAlist, self.FR_ch2_VAlist \
                = ch_list1, state_list_1, amp_list_1, dBm_list_1, [maxFrq_1, maxFrq_2], err1, err2, VertAcc_list2, VertAcc_list1
            else:
                self.FR_ch_list, self.FR_state, self.FR_amp, self.FR_dbm, self.FR_max_frq, self.FR_HF_err, self.FR_LF_err, self.FR_ch1_VAlist, self.FR_ch2_VAlist \
                = ch_list1, state_list_1, amp_list_1, dBm_list_1, [maxFrq_1, maxFrq_2], err1, err2, VertAcc_list1, VertAcc_list2
        elif self.adj_sch == '5-0':
            self.FR_ch_list, self.FR_state, self.FR_amp, self.FR_dbm, self.FR_max_frq, self.FR_HF_err, self.FR_LF_err, self.FR_ch1_VAlist, self.FR_ch2_VAlist \
            = ch_list1, state_list_1, amp_list_1, dBm_list_1, [maxFrq_1, maxFrq_3], err1, err2, VertAcc_list1, VertAcc_list1
        elif self.adj_sch in ['5-1', '5-2']:
            self.FR_ch_list, self.FR_state, self.FR_amp, self.FR_dbm, self.FR_max_frq, self.FR_HF_err, self.FR_LF_err, self.FR_ch1_VAlist, self.FR_ch2_VAlist \
            = ch_list1, state_list_1, amp_list_1, dBm_list_1, [maxFrq_1, maxFrq_2], err1, err2, VertAcc_list1, VertAcc_list1
        elif self.adj_sch == '2-0':
            self.FR_ch_list, self.FR_state, self.FR_amp, self.FR_dbm, self.FR_max_frq, self.FR_HF_err, self.FR_LF_err, self.FR_ch1_VAlist, self.FR_ch2_VAlist \
            = ch_list1, state_list_2, amp_list_2, dBm_list_2, [maxFrq_1]*8, err3, err3, VertAcc_list1, VertAcc_list1
        elif self.adj_sch == '1-X':
            self.FR_ch_list, self.FR_state, self.FR_amp, self.FR_dbm, self.FR_max_frq, self.FR_HF_err, self.FR_LF_err, self.FR_ch1_VAlist, self.FR_ch2_VAlist \
            =ch_list1, state_list_1, amp_list_1, dBm_list_1, [maxFrq_1]*2, err1, err2, VertAcc_list1, VertAcc_list1

class FrqCntParam(ParameterInit):
    def __init__(self):
        super(FrqCntParam, self).__init__()
        self.FrqCnt_config()
    def FrqCnt_config(self):
        #calibrating parameter
        self.cal_amp = 0.5 #
        self.cal_frq = 1000
        self.cal_err = 0.5
        self.cal_trgLvl = [1.2, 0]
        self.cal_reg = [0, 0]
        #testing parameter
        self.test_err = 5
        self.test_amp = [0.283, 1]
        self.test_ofst = [1.2, 0]
        self.test_frq = [10, 1000, 1000000]

class QAParam(ParameterInit):
    def __init__(self):
        super(QAParam, self).__init__()
        self.QA_config()
    def QA_config(self):  
        ch_list1         = ['C1', 'C2']
        ch_list2         = ['C1']
        DC_list1         = [0,0.01,0.1,1,3,10,-10,-3,-1,-0.1,-0.01]
        DC_list2         = [0,0.01,0.1,1,3,-3,-1,-0.1,-0.01]
        DC_err1          = 0.001
        DC_err2          = 0.0016
        DC_err3          = 0.003
        DutyMeas_list1    = [20.0, 30.0, 40.0, 50.0, 60.0, 70.0, 80.0]
        DutyMeas_list2    = [41.0, 45.0, 50.0, 55.0, 59.0]
        DutyMeas_err     = 0.8
        VA_AmpList1  = [11.0,5.6,2.0,0.9,0.4,0.142,0.064,0.022,0.010,0.004]
        VA_AmpList2  = [13.0,4.0,1.0,0.4,0.1,0.04,0.01,0.004]
        VA_OfstList = [0,3.5]
        VA_Frq      = 10000
        
        if self.adj_sch == '0-0':
            self.QA_ch_list, self.QA_ch1_dclist, self.QA_ch2_dclist, self.QA_dc_err, self.QA_duty_list, self.QA_duty_err, self.QA_ampList, self.QA_ofstList, self.QA_VA_Frq\
            = ch_list2, DC_list1, DC_list2, DC_err3, DutyMeas_list1, DutyMeas_err, VA_AmpList1, VA_OfstList, VA_Frq
        elif self.adj_sch == '1-0':
            if self.sign == 'WST':
                self.QA_ch_list, self.QA_ch1_dclist, self.QA_ch2_dclist, self.QA_dc_err, self.QA_duty_list, self.QA_duty_err, self.QA_ampList, self.QA_ofstList, self.QA_VA_Frq\
                = ch_list1, DC_list2, DC_list1, DC_err3, DutyMeas_list1, DutyMeas_err, VA_AmpList1, VA_OfstList, VA_Frq
            else:
                self.QA_ch_list, self.QA_ch1_dclist, self.QA_ch2_dclist, self.QA_dc_err, self.QA_duty_list, self.QA_duty_err, self.QA_ampList, self.QA_ofstList, self.QA_VA_Frq\
                = ch_list1, DC_list1, DC_list2, DC_err3, DutyMeas_list1, DutyMeas_err, VA_AmpList1, VA_OfstList, VA_Frq
        elif self.adj_sch in ['5-0', '5-1', '5-2']:
            self.QA_ch_list, self.QA_ch1_dclist, self.QA_ch2_dclist, self.QA_dc_err, self.QA_duty_list, self.QA_duty_err, self.QA_ampList, self.QA_ofstList, self.QA_VA_Frq\
            = ch_list1, DC_list1, DC_list1, DC_err1, DutyMeas_list1, DutyMeas_err, VA_AmpList1, VA_OfstList, VA_Frq
        elif self.adj_sch == '2-0':
            self.QA_ch_list, self.QA_ch1_dclist, self.QA_ch2_dclist, self.QA_dc_err, self.QA_duty_list, self.QA_duty_err, self.QA_ampList, self.QA_ofstList, self.QA_VA_Frq\
            = ch_list1, DC_list1, DC_list1, DC_err2, DutyMeas_list1, DutyMeas_err, VA_AmpList1, VA_OfstList, VA_Frq
        elif self.adj_sch == '1-X':
            self.QA_ch_list, self.QA_ch1_dclist, self.QA_ch2_dclist, self.QA_dc_err, self.QA_duty_list, self.QA_duty_err, self.QA_ampList, self.QA_ofstList, self.QA_VA_Frq\
            = ch_list1, DC_list1, DC_list1, DC_err3, DutyMeas_list2, DutyMeas_err, VA_AmpList2, VA_OfstList, VA_Frq
        
#-----------------------------------------------------------------------------
if __name__ == '__main__':
    sdg=ParameterInit()
    print sdg.adj_sch, sdg.model, sdg.band
    raw_input()
