#!/usr/bin/env python
#-*- coding:utf-8 –*-
#-----------------------------------------------------------------------------
# $Header: $
#-----------------------------------------------------------------------------
# Summary:           Implementation of Vertical Accuracy Calibration
#
# Authors:           Jensen.Cai
#
# Started:           11/25/2014
#
# Version:           V1.7R1
#
# Copyright 2013-2016 Siglent Corporation. All Rights Reserved.
#
#-----------------------------------------------------------------------------

import sys, time, math
sys.path.append(sys.path[0]+'\\Prod Lib')
from reminder import popup
from test_info import testInfo_show
from win32com_excel import *
from device_remote import *
from param import *
from file import *

#-----------------------------------------------------------------------------
class VertAccCalib(VAParam):
    def __init__(self):
        super(VertAccCalib, self).__init__()
        self.VA = VARemote()
        self.DMM = DMMRemote()
        self.fail_info = []
        self.row = 9

    def VACal_main(self):
        self.DMM.set_default()
        self.DMM.set_mode('AC')

        #生成报告文件并将设备信息写入文件头
        report = TestReport('VertAccCalib')
        xls_name = report.create()
        self.xls = easyExcel(xls_name)
        report.head_write(self.xls)

        print '\nStarting Vertical Accuracy Calibrate Process...\n'

        #垂直精度校正，从第9行开始写入数据
        self.row = 9
        self.VertAcc_calib()
        
        self.VA.save_adjData()
        time.sleep(self.save_time)
        
        print 'The Vertical Accuracy Calibrate Process is done\n'
        
        print 'Starting Vertical Accuracy Measure Process...\n'
        
        #垂直精度检测，从第50行开始写入数据
        self.row = 50
        self.VA_ch_list.reverse()
        self.VertAcc_meas()

    def VertAcc_calib(self):
        #开始进行垂直精度校正
        for ch_calib in self.VA_ch_list:
            self.VA.set_output_load(ch_calib, 'HZ')
            self.VA.set_bswv(ch_calib, 'SINE', 10000, 11)
            popup(u'注意! Notice!', \
                      u'请将万用表连接至%s 并断开另一通道\n\nPlease connect the DMM to %s and disconnect another channel' % (ch_calib,  ch_calib))
            self.VA.set_output_on(ch_calib)
    
            self.__DMM_check(ch_calib)
        
            for state_calib in range(0,len(self.VA_ofst_list)):
                ofst_calib = self.VA_ofst_list[state_calib]
                for idx_calib in range(0,len(self.VA_amp_list)):
                    amp_calib = self.VA_amp_list[idx_calib]
                    self.__comp_calc(ch_calib, self.VA_frq, idx_calib, amp_calib, state_calib, ofst_calib)
            
            self.VA.set_output_off(ch_calib)
            print '\n'

    def __DMM_check(self,  channel):
        #检查万用表是否正常工作
        read_val = self.DMM.get_value('AC')
        if read_val < 3.5 or read_val > 4.5:
            popup(u'警告! Warning!', \
                  u'读值%s超出范围，请检查万用表是否正常工作！\n\n%s is out of range!Please check that the DMM is operating well!' % (read_val, read_val))
            self.xls.save()
            self.xls.close()
            raw_input()
            exit()
            
    def __comp_calc(self, ch_adj, frq_adj, idx_adj, amp_adj, state_adj, ofst_adj):
        #计算垂直精度校正的补偿值
        self.VA.set_lowFrqAdj_bswv(ch_adj, frq_adj, amp_adj, ofst_adj)
        vrms_read = self.DMM.get_value('AC')
        vrms_adj = amp_adj * 0.35355
        comp_adj = round(20 * math.log10(vrms_adj / vrms_read),  4)
        print 'Calibrating Channel:%s, Amp=%sV, Offset=%sV, VrmsRead=%.6fV, VrmsCalib=%.6fV, compensation=%sdB' % (ch_adj, amp_adj, ofst_adj, vrms_read, vrms_adj, comp_adj)
        self.xls.setCell('Sheet1', self.row, 1, '%s' % ch_adj)
        self.xls.setCell('Sheet1', self.row, 2, '%s' % amp_adj)
        self.xls.setCell('Sheet1', self.row, 3, '%s' % ofst_adj)
        self.xls.setCell('Sheet1', self.row, 4, '%s' % vrms_adj)
        self.xls.setCell('Sheet1', self.row, 5, '%s' % vrms_read)
        self.xls.setCell('Sheet1', self.row, 6, '%s' % comp_adj)
        self.VA.set_lowFrqAdj_comp(ch_adj, state_adj, idx_adj, frq_adj, comp_adj)
        self.row += 1

    def VertAcc_meas(self):
        #开始进行垂直精度检测
        for ch_meas in self.VA_ch_list:
            if ch_meas == self.VA_ch_list[1]:
                popup(u'注意! Notice!', \
                  u'请将万用表连接至%s 并断开另一通道\n\nPlease connect the DMM to %s and disconnect another channel' % (ch_meas,  ch_meas))
            self.VA.set_output_on(ch_meas)
        
            self.VA.set_frq(ch_meas, self.VA_frq)
            for state_meas in range(0,2):
                ofst_meas = self.VA_ofst_list[state_meas]
                self.VA.set_ofst(ch_meas, ofst_meas)
                for idx_meas in range(0,len(self.VA_amp_list)):
                    amp_meas = self.VA_amp_list[idx_meas]
                    self.VA.set_amp(ch_meas, amp_meas)
                    self.__meas_check(ch_meas, self.VA_frq, amp_meas, ofst_meas)
            
            self.VA.set_output_off(ch_meas)
            print '\n'

    def __meas_check(self, ch_check, frq_check, amp_check, ofst_check):
        #判断检测值是否通过
        vrms_meas = self.DMM.get_value('AC')
        err = (amp_check * 0.01 + 0.001) * 0.8
        vpp_max = amp_check + err
        vpp_min = amp_check - err
        vpp_meas = vrms_meas / 0.35355
        if vpp_meas < vpp_min or vpp_meas > vpp_max:
            result = 'Fail'
            self.fail_info.append(u'%s 垂直精度%sV (偏置%sV)档位检测失败' % (ch_check, amp_check, ofst_check))
            self.fail_info.append('Vertical Accuracy Measure: %s %sV (Offset=%sV) Fail' % (ch_check, amp_check, ofst_check))
        else:
            result = 'Pass'
        print 'Checking Channel:%s, Amp=%sV, Offset=%sV, MeasuredVpp=%.6fV, %s' % (ch_check, amp_check, ofst_check, vpp_meas, result)
        self.xls.setCell('Sheet1', self.row, 1, '%s' % ch_check)
        self.xls.setCell('Sheet1', self.row, 2, '%s' % amp_check)
        self.xls.setCell('Sheet1', self.row, 3, '%s' % ofst_check)
        self.xls.setCell('Sheet1', self.row, 4, '%s' % vrms_meas)
        self.xls.setCell('Sheet1', self.row, 5, '%s' % vpp_meas)
        self.xls.setCell('Sheet1', self.row, 6, '%s ~ %s' % (vpp_min, vpp_max))
        self.xls.setCell('Sheet1', self.row, 7, '%s' % result)
        self.row += 1

    def saveAndClose(self):
        #保存报告文件并关闭
        self.xls.save()
        time.sleep(0.2)
        self.xls.close()
        time.sleep(0.2)
        
        self.VA.close()
        self.DMM.close()
        time.sleep(0.2)
        print 'The Vertical Accuracy Measure Process is done\n'

    def show_result(self):
        if self.fail_info == []:
            testInfo_show([u'垂直精度校正和检测通过，请进行下一步操作', 'Vertical Accuracy Calibrate: Pass'])
        else:
            self.fail_info.insert(0, u'垂直精度校正和检测失败')
            self.fail_info.insert(1, 'Vertical Accuracy Calibrate: Fail')
            testInfo_show(self.fail_info)
            
if __name__ == '__main__':
    proc = VertAccCalib()
    proc.VACal_main()
    proc.saveAndClose()
    proc.show_result()
